@@ -31,6 +31,7 @@
 #include <gtksourceview/gtksource.h>
 
 #include "gedit-app.h"
+#include "gedit-app-private.h"
 #include "gedit-view.h"
 #include "gedit-window.h"
 
@@ -388,7 +389,7 @@ gedit_settings_class_init (GeditSettingsClass *klass)
 	object_class->dispose = gedit_settings_dispose;
 }
 
-GObject *
+GeditSettings *
 gedit_settings_new ()
 {
 	return g_object_new (GEDIT_TYPE_SETTINGS, NULL);
